Learn R Programming

mitml (version 0.3-1)

mids2mitml.list: Convert objects of class mids to mitml.list

Description

This function converts a mids class object (from the mice package) to mitml.list, such that it may be managed and analyzed using the functions of this package.

Usage

mids2mitml.list(x)

Arguments

x
An object of class mids as produced by mice (see the mice package).

Value

  • A list of imputed data sets with an additional class attribute mitml.list.

See Also

mitmlComplete

Examples

Run this code
data(studentratings)

# imputation using mice
require(mice)
imp <- mice(studentratings)

implist <- mids2mitml.list(imp)

Run the code above in your browser using DataLab