Learn R Programming

mitml (version 0.3-1)

mitml-package: mitml: Tools for multiple imputation in multilevel modeling

Description

Provides tools for multiple imputation of missing data in multilevel modeling. This package includes a user-friendly interface to the algorithms implemented in the pan and the jomo package, as well as several functions for visualizing, managing and the analyzing multiply imputed data sets.

The main interface to pan is the function panImpute, which allows specification of a wide array of imputation models. In addition, the function jomoImpute provides an interface to jomo, further extending the functionality of pan. Imputations are efficiently stored in objects of class mitml. In order to obtain the completed (i.e., imputed) data sets from those objects, mitmlComplete is used, which produces a list of imputed data sets (class mitml.list) that can be used in further analyses.

Several functions have been added to allow for convenient analysis of multiply imputed data sets. The functions with and within may be used for manipulating the data sets and for fitting statistical models. Parameter estimates can be extracted using testEstimates. Single- and multi-parameter hypotheses tests can be performed using testConstraints and testModels. In addition, the anova method provides a simple interface to model comparisons.

Data sets can be imported and exported from or to different statistical software packages. Currently, write.mitmlMplus, write.mitmlSAV and write.mitmlSPSS export data sets to Mplus and SPSS, while other functions import previously imputed data from within R.

Finally, the package supplies tools for summarizing and visualizing imputation models, which is useful for the assessment of convergence and the reporting of results.

Arguments