Learn R Programming

mitml (version 0.3-1)

read.mitml: Read mitml objects from file

Description

This function loads mitml class objects from native R formats.

Usage

read.mitml(filename)

Arguments

filename
Name of the file to read, to be specified with file extension (e.g., .R, .Rdata).

Value

  • Returns the saved mitml class object.

See Also

panImpute, jomoImpute, write.mitml

Examples

Run this code
data(studentratings)

fml <- ReadDis + SES ~ ReadAchiev + (1|ID)
imp <- panImpute(studentratings, formula=fml, n.burn=1000, n.iter=100, m=5)

# write 'mitml' object
write.mitml(imp, filename="imputation.R")

# read previously saved 'mitml' object
previous.imp <- read.mitml("imputation.R")

class(previous.imp)
previous.imp

Run the code above in your browser using DataLab