In addition, the data set features the ID of 50 different schools (i.e., clusters), the biological sex of all students, and a broad, additional grouping factor. Different amounts of missing data have been inserted into the data set in a completely random fashion.
All data are completely fictional, and thus should not be interpreted as if they were real.
data(studentratings)