Learn R Programming

mitml (version 0.3-1)

summary.mitml: Summary measures for imputation models

Description

Provides summary statistics and additional information regarding the imputation process.

Usage

## S3 method for class 'mitml':
summary(object, n.Rhat=3, goodness.of.appr=FALSE, ...)

Arguments

object
An object of class mitml as produced by panImpute and jomoImpute.
n.Rhat
(optional) An integer denoting the number of sequences used for calculating the potential scale reduction factor. Default is to 3.
goodness.of.appr
(optional) A logical flag indicating if the goodness of approximation should be printed. Default is to FALSE (see Note).
...
Not being used.

Value

  • Returns an object of class summary.mitml. A print method is used for better readable console output.

Details

The summary method calculates summary statistics for objects of class mitml, gives information on the imputation process, and the amount of missing data per variable.

The output includes the potential scale reduction factor (PSRF, or $\hat{R}$), which is calculated for each parameter of the imputation model as a measure of convergence (Gelman and Rubin, 1992). Calculation of the PSRFs can be suppressed by setting n.Rhat=NULL.

References

Gelman, A., and Rubin, D. B. (1992). Inference from iterative simulation using multiple sequences. Statistical Science, 7, 457-472.

Hoff, P. D. (2009). A first course in Bayesian statistical methods. New York, NY: Springer.

See Also

panImpute,jomoImpute

Examples

Run this code
data(studentratings)

fml <- ReadDis + SES ~ ReadAchiev + (1|ID)
imp <- panImpute(studentratings, formula=fml, n.burn=1000, n.iter=100, m=5)

# print summary
summary(imp)

Run the code above in your browser using DataLab